package com.wjp.modules.mp.controller;

import com.github.xiaoymin.knife4j.annotations.Ignore;
import com.wjp.common.annotation.LogOperation;
import com.wjp.common.constant.Constant;
import com.wjp.common.page.PageData;
import com.wjp.common.utils.Result;
import com.wjp.common.validator.AssertUtils;
import com.wjp.common.validator.ValidatorUtils;
import com.wjp.common.validator.group.AddGroup;
import com.wjp.common.validator.group.DefaultGroup;
import com.wjp.common.validator.group.UpdateGroup;
import com.wjp.modules.mp.dto.MpAccountDTO;
import com.wjp.modules.mp.service.MpAccountService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.web.bind.annotation.*;

import java.util.Map;


/**
 * 公众号账号管理
 *
 * @author Toby javatangbin@163.com
 */
@AllArgsConstructor
@RestController
@RequestMapping("mp/account")
@Tag(name = "公众号账号管理")
public class MpAccountController {
    private final MpAccountService mpAccountService;

    @GetMapping("page")
    @Operation(summary = "分页")
    @Parameters({
            @Parameter(name = Constant.PAGE, description = "当前页码，从1开始", required = true),
            @Parameter(name = Constant.LIMIT, description = "每页显示记录数", required = true),
            @Parameter(name = Constant.ORDER_FIELD, description = "排序字段"),
            @Parameter(name = Constant.ORDER, description = "排序方式，可选值(asc、desc)")
    })
    @RequiresPermissions("mp:account:all")
    public Result<PageData<MpAccountDTO>> page(@Parameter(hidden = true) @RequestParam Map<String, Object> params) {
        PageData<MpAccountDTO> page = mpAccountService.page(params);

        return new Result<PageData<MpAccountDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @Operation(summary = "信息")
    @RequiresPermissions("mp:account:all")
    public Result<MpAccountDTO> get(@PathVariable("id") Long id) {
        MpAccountDTO data = mpAccountService.get(id);

        return new Result<MpAccountDTO>().ok(data);
    }

    @PostMapping
    @Operation(summary = "保存")
    @LogOperation("保存")
    @RequiresPermissions("mp:account:all")
    public Result save(@RequestBody MpAccountDTO dto) {
        //效验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        mpAccountService.save(dto);

        return new Result();
    }

    @PutMapping
    @Operation(summary = "修改")
    @LogOperation("修改")
    @RequiresPermissions("mp:account:all")
    public Result update(@RequestBody MpAccountDTO dto) {
        //效验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        mpAccountService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @Operation(summary = "删除")
    @LogOperation("删除")
    @RequiresPermissions("mp:account:all")
    public Result delete(@RequestBody Long[] ids) {
        //效验数据
        AssertUtils.isArrayEmpty(ids, "id");

        mpAccountService.delete(ids);

        return new Result();
    }

}