/**
 * Copyright (c) 2018 Toby All rights reserved.
 *
 * https://www.scjydz.com
 *
 * 版权所有，侵权必究！
 */

package com.wjp.exception;

import com.wjp.common.exception.ErrorCode;
import com.wjp.common.exception.MyException;
import com.wjp.common.utils.Result;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

/**
 * 异常处理器
 *
 * @author Toby javatangbin@163.com
 * @since 1.0.0
 */
@RestControllerAdvice
public class MyExceptionHandler {
	private static final Logger logger = LoggerFactory.getLogger(MyExceptionHandler.class);

	/**
	 * 处理自定义异常
	 */
	@ExceptionHandler(MyException.class)
	public Result handleMyException(MyException ex){
		Result result = new Result();
		result.error(ex.getCode(), ex.getMsg());

		return result;
	}

	@ExceptionHandler(DuplicateKeyException.class)
	public Result handleDuplicateKeyException(DuplicateKeyException ex){
		Result result = new Result();
		result.error(ErrorCode.DB_RECORD_EXISTS);

		return result;
	}

	@ExceptionHandler(Exception.class)
	public Result handleException(Exception ex){
		logger.error(ex.getMessage(), ex);

		return new Result().error();
	}
}